#!/usr/bin/env python
##############################################################################
#
# pyobjcryst
#
# File coded by:    Vincent Favre-Nicolin
#
# See AUTHORS.txt for a list of people who contributed.
# See LICENSE.txt for license information.
#
##############################################################################

"""Python wrapping of PowderPattern.h

See the online ObjCryst++ documentation (https://objcryst.readthedocs.io).

Changes from ObjCryst::ReflectionProfile::
        In development !
"""

__all__ = ["ReflectionProfile", "ReflectionProfileType"]

from pyobjcryst._pyobjcryst import ReflectionProfile
from pyobjcryst._pyobjcryst import ReflectionProfileType
